@@ -350,7 +350,7 @@ class HTMLTestRunner(CustomTemplate):
         RunResult.passed = result.success_count
         RunResult.failed = result.failure_count
         RunResult.errors = result.error_count
-        RunResult.Skiped = result.skip_count
+        RunResult.skiped = result.skip_count
         if result.success_count:
             status.append('Passed:%s' % result.success_count)
         if result.failure_count:
@@ -576,7 +576,7 @@ class SMTP(object):
 
         smtp = smtplib.SMTP()
         try:
-            smtp.connect(self.host)
+            smtp.connect(self.host, self.port)
             smtp.login(self.user, self.password)
             smtp.sendmail(self.user, to, msg.as_string())
             log.info(" 📧 Email sent successfully!!")
