@@ -1,7 +1,8 @@
 # coding=utf-8
 import time
 import platform
-import warnings
+from selenium.webdriver import Chrome
+from selenium.webdriver.remote.webdriver import WebDriver as SeleniumWebDriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support.select import Select
@@ -10,6 +11,9 @@ from seldom.logging import log
 from seldom.running.config import Seldom
 from seldom.logging.exceptions import NotFindElementError
 
+__all__ = ["WebDriver"]
+
+
 LOCATOR_LIST = {
     'css': By.CSS_SELECTOR,
     'id_': By.ID,
@@ -35,17 +39,17 @@ class WebElement(object):
             LOCATOR_LIST[self.by]
         except KeyError:
             raise ValueError("Element positioning of type '{}' is not supported. ".format(self.by))
+        self.find_elem_info = None
 
-    @staticmethod
-    def __find_element(elem):
+    def __find_element(self, elem):
         """
         Find if the element exists.
         """
         for _ in range(Seldom.timeout):
             elems = Seldom.driver.find_elements(by=elem[0], value=elem[1])
             if len(elems) >= 1:
-                log.info("✅ Find {number} element: {by}={value} ".format(
-                    number=str(len(elems)), by=elem[0], value=elem[1]))
+                self.find_elem_info = "Find {number} element: {by}={value} ".format(
+                    number=str(len(elems)), by=elem[0], value=elem[1])
                 break
             else:
                 time.sleep(1)
@@ -117,6 +121,10 @@ class WebElement(object):
             time.sleep(0.3)
             Seldom.driver.execute_script(style_null, elem)
 
+    @property
+    def info(self):
+        return self.find_elem_info
+
 
 class WebDriver(object):
     """
@@ -124,70 +132,83 @@ class WebDriver(object):
     selenium provided by the method of the two packaging,
     making it easier to use.
     """
-    original_window = None
 
     class Keys:
         """
         Achieve keyboard shortcuts
+
         Usage:
             self.Keys(id_="kw").enter()
         """
 
         def __init__(self, index=0, **kwargs):
-            web_elem = WebElement(**kwargs)
-            self.elem = web_elem.get_elements()[index]
-            web_elem.show_element(self.elem)
+            self.web_elem = WebElement(**kwargs)
+            self.elem = self.web_elem.get_elements()[index]
+            self.web_elem.show_element(self.elem)
 
         def input(self, text=""):
+            log.info("✅ {info}, input '{text}'.".format(info=self.web_elem.info, text=text))
             self.elem.send_keys(text)
 
         def enter(self):
+            log.info("✅ {info}, enter.".format(info=self.web_elem.info))
             self.elem.send_keys(Keys.ENTER)
 
         def select_all(self):
+            log.info("✅ {info}, ctrl+a.".format(info=self.web_elem.info))
             if platform.system().lower() == "darwin":
                 self.elem.send_keys(Keys.COMMAND, "a")
             else:
                 self.elem.send_keys(Keys.CONTROL, "a")
 
         def cut(self):
+            log.info("✅ {info}, ctrl+x.".format(info=self.web_elem.info))
             if platform.system().lower() == "darwin":
                 self.elem.send_keys(Keys.COMMAND, "x")
             else:
                 self.elem.send_keys(Keys.CONTROL, "x")
 
         def copy(self):
+            log.info("✅ {info}, ctrl+c.".format(info=self.web_elem.info))
             if platform.system().lower() == "darwin":
                 self.elem.send_keys(Keys.COMMAND, "c")
             else:
                 self.elem.send_keys(Keys.CONTROL, "c")
 
         def paste(self):
+            log.info("✅ {info}, ctrl+v.".format(info=self.web_elem.info))
             if platform.system().lower() == "darwin":
                 self.elem.send_keys(Keys.COMMAND, "v")
             else:
                 self.elem.send_keys(Keys.CONTROL, "v")
 
         def backspace(self):
+            log.info("✅ {info}, backspace.".format(info=self.web_elem.info))
             self.elem.send_keys(Keys.BACKSPACE)
 
         def delete(self):
+            log.info("✅ {info}, delete.".format(info=self.web_elem.info))
             self.elem.send_keys(Keys.DELETE)
 
         def tab(self):
+            log.info("✅ {info}, tab.".format(info=self.web_elem.info))
             self.elem.send_keys(Keys.TAB)
 
         def space(self):
+            log.info("✅ {info}, space.".format(info=self.web_elem.info))
             self.elem.send_keys(Keys.SPACE)
 
     @staticmethod
-    def get(url):
+    def visit(url):
         """
-        get url.
+        visit url.
 
         Usage:
-        self.get("https://www.baidu.com")
+            self.visit("https://www.baidu.com")
         """
+        log.info("📖 {}".format(url))
+        if isinstance(Seldom.driver, SeleniumWebDriver) is False:
+            Seldom.driver = Chrome()
         Seldom.driver.get(url)
 
     def open(self, url):
@@ -195,9 +216,9 @@ class WebDriver(object):
         open url.
 
         Usage:
-        self.open("https://www.baidu.com")
+            self.open("https://www.baidu.com")
         """
-        self.get(url)
+        self.visit(url)
 
     @staticmethod
     def max_window():
@@ -205,7 +226,7 @@ class WebDriver(object):
         Set browser window maximized.
 
         Usage:
-        self.max_window()
+            self.max_window()
         """
         Seldom.driver.maximize_window()
 
@@ -215,7 +236,7 @@ class WebDriver(object):
         Set browser window wide and high.
 
         Usage:
-        self.set_window(wide,high)
+            self.set_window(wide,high)
         """
         Seldom.driver.set_window_size(wide, high)
 
@@ -224,14 +245,14 @@ class WebDriver(object):
         Operation input box.
 
         Usage:
-        self.type(css="#el", text="selenium")
+            self.type(css="#el", text="selenium")
         """
         if clear is True:
             self.clear(index, **kwargs)
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
-        log.info("🖋 input '{text}'.".format(text=text))
+        log.info("✅ {info}, input '{text}'.".format(info=web_elem.info, text=text))
         elem.send_keys(text)
         if enter is True:
             elem.send_keys(Keys.ENTER)
@@ -241,14 +262,14 @@ class WebDriver(object):
         Enter text and enter directly.
 
         Usage:
-        self.type_enter(css="#el", text="selenium")
+            self.type_enter(css="#el", text="selenium")
         """
         if clear is True:
             self.clear(index, **kwargs)
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
-        log.info("🖋 ➕ 🖱 input '{text}' and enter.".format(text=text))
+        log.info("✅ {info}, input '{text}' and enter.".format(info=web_elem.info, text=text))
         elem.send_keys(text)
         elem.send_keys(Keys.ENTER)
 
@@ -258,11 +279,12 @@ class WebDriver(object):
         Clear the contents of the input box.
 
         Usage:
-        self.clear(css="#el")
+            self.clear(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, clear input.".format(web_elem.info))
         elem.clear()
 
     @staticmethod
@@ -272,25 +294,26 @@ class WebDriver(object):
         Connection, check box, radio buttons, and even drop-down box etc..
 
         Usage:
-        self.click(css="#el")
+            self.click(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
-        log.info("🖱 click.")
+        log.info("✅ {}, click.".format(web_elem.info))
         elem.click()
 
     @staticmethod
     def slow_click(index=0, **kwargs):
         """
         Moving the mouse to the middle of an element. and click element.
+
         Usage:
-        self.slow_click(css="#el")
+            self.slow_click(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
-        log.info("🖱 slow click.")
+        log.info("✅ {}, slow click.".format(web_elem.info))
         ActionChains(Seldom.driver).move_to_element(elem).click(elem).perform()
 
     @staticmethod
@@ -299,11 +322,12 @@ class WebDriver(object):
         Right click element.
 
         Usage:
-        self.right_click(css="#el")
+            self.right_click(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, right click.".find(web_elem.info))
         ActionChains(Seldom.driver).context_click(elem).perform()
 
     @staticmethod
@@ -312,11 +336,12 @@ class WebDriver(object):
         Mouse over the element.
 
         Usage:
-        self.move_to_element(css="#el")
+            self.move_to_element(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, move to element.".format(web_elem.info))
         ActionChains(Seldom.driver).move_to_element(elem).perform()
 
     @staticmethod
@@ -325,11 +350,12 @@ class WebDriver(object):
         Mouse over the element.
 
         Usage:
-        self.move_to_element(css="#el")
+            self.move_to_element(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, click and hold.".format(web_elem.info))
         ActionChains(Seldom.driver).click_and_hold(elem).perform()
 
     @staticmethod
@@ -347,6 +373,7 @@ class WebDriver(object):
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
         action = ActionChains(Seldom.driver)
+        log.info("✅ {}, drag and drop by offset.".format(web_elem.info))
         action.drag_and_drop_by_offset(elem, x, y).perform()
 
     @staticmethod
@@ -355,11 +382,12 @@ class WebDriver(object):
         Double click element.
 
         Usage:
-        self.double_click(css="#el")
+            self.double_click(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, double click.".format(web_elem.info))
         ActionChains(Seldom.driver).double_click(elem).perform()
 
     @staticmethod
@@ -368,12 +396,12 @@ class WebDriver(object):
         Click the element by the link text
 
         Usage:
-        self.click_text("新闻")
+            self.click_text("新闻")
         """
         web_elem = WebElement(link_text=text)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
-        log.info("🖱 click link.")
+        log.info("✅ {}, click link.".format(web_elem.info))
         elem.click()
 
     @staticmethod
@@ -382,7 +410,7 @@ class WebDriver(object):
         Closes the current window.
 
         Usage:
-        self.close()
+            self.close()
         """
         Seldom.driver.close()
 
@@ -392,7 +420,7 @@ class WebDriver(object):
         Quit the driver and close all the windows.
 
         Usage:
-        self.quit()
+            self.quit()
         """
         Seldom.driver.quit()
 
@@ -402,11 +430,12 @@ class WebDriver(object):
         Submit the specified form.
 
         Usage:
-        driver.submit(css="#el")
+            driver.submit(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, submit.".format(web_elem.info))
         elem.submit()
 
     @staticmethod
@@ -415,8 +444,9 @@ class WebDriver(object):
         Refresh the current page.
 
         Usage:
-        self.refresh()
+            self.refresh()
         """
+        log.info("🔄️ refresh page.")
         Seldom.driver.refresh()
 
     @staticmethod
@@ -425,15 +455,16 @@ class WebDriver(object):
         Execute JavaScript scripts.
 
         Usage:
-        self.execute_script("window.scrollTo(200,1000);")
+            self.execute_script("window.scrollTo(200,1000);")
         """
         return Seldom.driver.execute_script(script, *args)
 
     def window_scroll(self, width=None, height=None):
         """
         Setting width and height of window scroll bar.
+
         Usage:
-        self.window_scroll(width=300, height=500)
+            self.window_scroll(width=300, height=500)
         """
         if width is None:
             width = "0"
@@ -445,8 +476,9 @@ class WebDriver(object):
     def element_scroll(self, css, width=None, height=None):
         """
         Setting width and height of element scroll bar.
+
         Usage:
-        self.element_scroll(css=".class", width=300, height=500)
+            self.element_scroll(css=".class", width=300, height=500)
         """
         if width is None:
             width = "0"
@@ -463,13 +495,14 @@ class WebDriver(object):
         Gets the value of an element attribute.
 
         Usage:
-        self.get_attribute(css="#el", attribute="type")
+            self.get_attribute(css="#el", attribute="type")
         """
         if attribute is None:
             raise ValueError("attribute is not None")
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {info}, get attribute：{att}.".format(info=web_elem.info, att=attribute))
         return elem.get_attribute(attribute)
 
     @staticmethod
@@ -478,11 +511,12 @@ class WebDriver(object):
         Get element text information.
 
         Usage:
-        self.get_text(css="#el")
+            self.get_text(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {info}, get text: {text}.".format(info=web_elem.info, text=elem.text))
         return elem.text
 
     @staticmethod
@@ -491,12 +525,14 @@ class WebDriver(object):
         Gets the element to display,The return result is true or false.
 
         Usage:
-        self.get_display(css="#el")
+            self.get_display(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
-        return elem.is_displayed()
+        result = elem.is_displayed()
+        log.info("✅ {info}, element is display: {r}.".format(info=web_elem.info, r=result))
+        return result
 
     @property
     def get_title(self):
@@ -504,8 +540,9 @@ class WebDriver(object):
         Get window title.
 
         Usage:
-        self.get_title()
+            self.get_title()
         """
+        log.info("✅ get title: {}.".format(Seldom.driver.title))
         return Seldom.driver.title
 
     @property
@@ -514,8 +551,9 @@ class WebDriver(object):
         Get the URL address of the current page.
 
         Usage:
-        self.get_url()
+            self.get_url()
         """
+        log.info("✅ get current url: {}.".format(Seldom.driver.current_url))
         return Seldom.driver.current_url
 
     @property
@@ -524,8 +562,9 @@ class WebDriver(object):
         Gets the text of the Alert.
 
         Usage:
-        self.get_alert_text()
+            self.get_alert_text()
         """
+        log.info("✅ alert text: {}.".format(Seldom.driver.switch_to.alert.text))
         return Seldom.driver.switch_to.alert.text
 
     @staticmethod
@@ -534,8 +573,9 @@ class WebDriver(object):
         Implicitly wait.All elements on the page.
 
         Usage:
-        self.wait(10)
+            self.wait(10)
         """
+        log.info("⌛️ implicitly wait: {}s.".format(str(secs)))
         Seldom.driver.implicitly_wait(secs)
 
     @staticmethod
@@ -544,8 +584,9 @@ class WebDriver(object):
         Accept warning box.
 
         Usage:
-        self.accept_alert()
+            self.accept_alert()
         """
+        log.info("✅ accept alert.")
         Seldom.driver.switch_to.alert.accept()
 
     @staticmethod
@@ -554,8 +595,9 @@ class WebDriver(object):
         Dismisses the alert available.
 
         Usage:
-        self.dismiss_alert()
+            self.dismiss_alert()
         """
+        log.info("✅ dismiss alert.")
         Seldom.driver.switch_to.alert.dismiss()
 
     @staticmethod
@@ -564,11 +606,12 @@ class WebDriver(object):
         Switch to the specified frame.
 
         Usage:
-        self.switch_to_frame(css="#el")
+            self.switch_to_frame(css="#el")
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, switch to frame.".format(web_elem.info))
         Seldom.driver.switch_to.frame(elem)
 
     @staticmethod
@@ -578,74 +621,25 @@ class WebDriver(object):
         Corresponding relationship with switch_to_frame () method.
 
         Usage:
-        self.switch_to_frame_out()
+            self.switch_to_frame_out()
         """
+        log.info("✅ switch to frame out.")
         Seldom.driver.switch_to.default_content()
 
     @staticmethod
-    def open_new_window(index=0, **kwargs):
-        """
-        Open the new window and switch the handle to the newly opened window.
-
-        Usage:
-        self.open_new_window(link_text="注册")
-        """
-        warnings.warn("This method is not recommended",
-                      DeprecationWarning, stacklevel=2)
-        original_window = Seldom.driver.current_window_handle
-        web_elem = WebElement(**kwargs)
-        elem = web_elem.get_elements()[index]
-        web_elem.show_element(elem)
-        elem.click()
-        all_handles = Seldom.driver.window_handles
-        for handle in all_handles:
-            if handle != original_window:
-                Seldom.driver.switch_to.window(handle)
-
-    @property
-    def current_window_handle(self):
-        """
-        Returns the handle of the current window.
-
-        :Usage:
-            self.current_window_handle
-        """
-        return Seldom.driver.current_window_handle
-
-    @property
-    def new_window_handle(self):
-        """
-        Returns the handle of the new window.
-
-        :Usage:
-            self.new_window_handle
-        """
-        new_handle = self.window_handles
-        return new_handle[-1]
-
-    @property
-    def window_handles(self):
-        """
-        Returns the handles of all windows within the current session.
-
-        :Usage:
-            self.window_handles
-        """
-        all_handles = Seldom.driver.window_handles
-        return all_handles
-
-    @staticmethod
-    def switch_to_window(window_name):
+    def switch_to_window(window):
         """
         Switches focus to the specified window.
 
         :Args:
-         - window_name: The name or window handle of the window to switch to.
+         - window: window index. 1 represents a newly opened window (0 is the first one)
 
         :Usage:
-            self.switch_to_window('main')
+            self.switch_to_window(1)
         """
-        Seldom.driver.switch_to.window(window_name)
+        log.info("✅ switch to the {} window.".format(str(window)))
+        all_handles = Seldom.driver.window_handles
+        Seldom.driver.switch_to.window(all_handles[window])
 
     @staticmethod
     def screenshots(file_path):
@@ -655,6 +649,7 @@ class WebDriver(object):
         Usage:
         self.screenshots('/Screenshots/foo.png')
         """
+        log.info("📷️  screenshot.")
         Seldom.driver.save_screenshot(file_path)
 
     @staticmethod
@@ -681,6 +676,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
         web_elem.show_element(elem)
+        log.info("✅ {}, select option.".format(web_elem.info))
         if value is not None:
             Select(elem).select_by_value(value)
         elif text is not None:
@@ -765,6 +761,7 @@ class WebDriver(object):
         Usage:
             self.sleep(seconds)
         """
+        log.info("💤️ sleep: {}s.".format(str(sec)))
         time.sleep(sec)
 
     @staticmethod
@@ -800,6 +797,7 @@ class WebDriver(object):
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()
+        log.info("✅ {}.".format(web_elem.info))
         return elem
 
     @staticmethod
@@ -813,4 +811,5 @@ class WebDriver(object):
         """
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements()[index]
+        log.info("✅ {}.".format(web_elem.info))
         return elem
